@@ -8,8 +8,9 @@ supporting document conversion, OCR, layout analysis, and table recognition.
 from .client import DatalabClient, AsyncDatalabClient
 from .exceptions import DatalabError, DatalabAPIError, DatalabTimeoutError
 from .models import ConversionResult, OCRResult, ConvertOptions, OCROptions
+from .settings import settings
 
-__version__ = "1.0.0"
+__version__ = settings.VERSION
 __all__ = [
     "DatalabClient",
     "AsyncDatalabClient",
